@@ -1,5 +1,5 @@
 ;;;
-;;; Copyright (c) 2003-2006 uim Project http://uim.freedesktop.org/
+;;; Copyright (c) 2003-2008 uim Project http://code.google.com/p/uim/
 ;;;
 ;;; All rights reserved.
 ;;;
@@ -43,7 +43,6 @@
     ((("8" "1"))(""))
     ((("9" "1"))(""))
     ((("0" "1"))(""))
-    ((("'" "1"))(""))
     ((("," "1"))(""))
     ((("." "1"))(""))
     ((("p" "1"))(""))
@@ -73,7 +72,7 @@
     ((("w" "1"))(""))
     ((("v" "1"))(""))
     ((("z" "1"))(""))
-    ((("\057" "1"))(""))
+    ((("/" "1"))(""))
     ((("1" "2"))(""))
     ((("2" "2"))(""))
     ((("3" "2"))(""))
@@ -84,7 +83,6 @@
     ((("8" "2"))(""))
     ((("9" "2"))(""))
     ((("0" "2"))(""))
-    ((("'" "2"))(""))
     ((("," "2"))(""))
     ((("." "2"))(""))
     ((("p" "2"))(""))
@@ -114,7 +112,7 @@
     ((("w" "2"))(""))
     ((("v" "2"))(""))
     ((("z" "2"))(""))
-    ((("\057" "2"))(""))
+    ((("/" "2"))(""))
     ((("1" "3"))(""))
     ((("2" "3"))(""))
     ((("3" "3"))(""))
@@ -125,7 +123,6 @@
     ((("8" "3"))(""))
     ((("9" "3"))(""))
     ((("0" "3"))(""))
-    ((("'" "3"))(""))
     ((("," "3"))(""))
     ((("." "3"))(""))
     ((("p" "3"))(""))
@@ -155,7 +152,7 @@
     ((("w" "3"))(""))
     ((("v" "3"))(""))
     ((("z" "3"))(""))
-    ((("\057" "3"))(""))
+    ((("/" "3"))(""))
     ((("1" "4"))(""))
     ((("2" "4"))(""))
     ((("3" "4"))(""))
@@ -166,7 +163,6 @@
     ((("8" "4"))(""))
     ((("9" "4"))(""))
     ((("0" "4"))(""))
-    ((("'" "4"))(""))
     ((("," "4"))("ɧ"))
     ((("." "4"))(""))
     ((("p" "4"))(""))
@@ -196,7 +192,7 @@
     ((("w" "4"))(""))
     ((("v" "4"))(""))
     ((("z" "4"))(""))
-    ((("\057" "4"))("")) 
+    ((("/" "4"))("")) 
     ((("1" "5"))(""))
     ((("2" "5"))(""))
     ((("3" "5"))(""))
@@ -207,7 +203,6 @@
     ((("8" "5"))(""))
     ((("9" "5"))(""))
     ((("0" "5"))(""))
-    ((("'" "5"))(""))
     ((("," "5"))(""))
     ((("." "5"))(""))
     ((("p" "5"))(""))
@@ -237,7 +232,7 @@
     ((("w" "5"))("˿"))
     ((("v" "5"))(""))
     ((("z" "5"))(""))
-    ((("\057" "5"))(""))
+    ((("/" "5"))(""))
     ((("1" "6"))(""))
     ((("2" "6"))(""))
     ((("3" "6"))(""))
@@ -248,7 +243,6 @@
     ((("8" "6"))(""))
     ((("9" "6"))(""))
     ((("0" "6"))(""))
-    ((("'" "6"))(""))
     ((("," "6"))(""))
     ((("." "6"))(""))
     ((("p" "6"))(""))
@@ -278,7 +272,7 @@
     ((("w" "6"))(""))
     ((("v" "6"))(""))
     ((("z" "6"))(""))
-    ((("\057" "6"))(""))
+    ((("/" "6"))(""))
     ((("1" "7"))(""))
     ((("2" "7"))(""))
     ((("3" "7"))(""))
@@ -289,7 +283,6 @@
     ((("8" "7"))(""))
     ((("9" "7"))(""))
     ((("0" "7"))(""))
-    ((("'" "7"))(""))
     ((("," "7"))(""))
     ((("." "7"))(""))
     ((("p" "7"))(""))
@@ -319,7 +312,7 @@
     ((("w" "7"))(""))
     ((("v" "7"))(""))
     ((("z" "7"))(""))
-    ((("\057" "7"))(""))
+    ((("/" "7"))(""))
     ((("1" "8"))(""))
     ((("2" "8"))(""))
     ((("3" "8"))(""))
@@ -330,7 +323,6 @@
     ((("8" "8"))(""))
     ((("9" "8"))(""))
     ((("0" "8"))(""))
-    ((("'" "8"))(""))
     ((("," "8"))(""))
     ((("." "8"))(""))
     ((("p" "8"))(""))
@@ -360,7 +352,7 @@
     ((("w" "8"))(""))
     ((("v" "8"))("ε"))
     ((("z" "8"))(""))
-    ((("\057" "8"))(""))
+    ((("/" "8"))(""))
     ((("1" "9"))(""))
     ((("2" "9"))(""))
     ((("3" "9"))(""))
@@ -371,10 +363,9 @@
     ((("8" "9"))(""))
     ((("9" "9"))(""))
     ((("0" "9"))(""))
-    ((("'" "9"))(""))
     ((("," "9"))(""))
     ((("." "9"))(""))
-    ((("p" "9"))(""))
+    ((("p" "9"))("Ģ"))
     ((("y" "9"))(""))
     ((("f" "9"))(""))
     ((("g" "9"))(""))
@@ -401,7 +392,7 @@
     ((("w" "9"))(""))
     ((("v" "9"))("ð"))
     ((("z" "9"))(""))
-    ((("\057" "9"))(""))
+    ((("/" "9"))(""))
     ((("1" "0"))(""))
     ((("2" "0"))(""))
     ((("3" "0"))(""))
@@ -412,7 +403,6 @@
     ((("8" "0"))(""))
     ((("9" "0"))(""))
     ((("0" "0"))(""))
-    ((("'" "0"))(""))
     ((("," "0"))(""))
     ((("." "0"))(""))
     ((("p" "0"))(""))
@@ -442,47 +432,7 @@
     ((("w" "0"))(""))
     ((("v" "0"))(""))
     ((("z" "0"))(""))
-    ((("\057" "0"))(""))
-    ((("1" "'"))(""))
-    ((("2" "'"))(""))
-    ((("3" "'"))(""))
-    ((("4" "'"))(""))
-    ((("5" "'"))(""))
-    ((("6" "'"))(""))
-    ((("7" "'"))(""))
-    ((("8" "'"))(""))
-    ((("9" "'"))(""))
-    ((("0" "'"))(""))
-    ((("'" "'"))(""))
-    ((("," "'"))(""))
-    ((("." "'"))(""))
-    ((("p" "'"))(""))
-    ((("y" "'"))(""))
-    ((("f" "'"))(""))
-    ((("g" "'"))(""))
-    ((("c" "'"))(""))
-    ((("r" "'"))(""))
-    ((("l" "'"))(""))
-    ((("a" "'"))(""))
-    ((("o" "'"))(""))
-    ((("e" "'"))(""))
-    ((("u" "'"))(""))
-    ((("i" "'"))(""))
-    ((("d" "'"))(""))
-    ((("h" "'"))(""))
-    ((("t" "'"))(""))
-    ((("n" "'"))(""))
-    ((("s" "'"))(""))
-    (((";" "'"))(""))
-    ((("q" "'"))(""))
-    ((("j" "'"))(""))
-    ((("k" "'"))(""))
-    ((("x" "'"))(""))
-    ((("b" "'"))(""))
-    ((("m" "'"))(""))
-    ((("w" "'"))(""))
-    ((("v" "'"))(""))
-    ((("z" "'"))(""))
+    ((("/" "0"))(""))
     ((("1" ","))("α"))
     ((("2" ","))(""))
     ((("3" ","))(""))
@@ -493,7 +443,6 @@
     ((("8" ","))(""))
     ((("9" ","))(""))
     ((("0" ","))(""))
-    ((("'" ","))(""))
     ((("," ","))(""))
     ((("." ","))(""))
     ((("p" ","))(""))
@@ -523,7 +472,7 @@
     ((("w" ","))(""))
     ((("v" ","))(""))
     ((("z" ","))(""))
-    ((("\057" ","))(""))
+    ((("/" ","))(""))
     ((("1" "."))(""))
     ((("2" "."))(""))
     ((("3" "."))("?"))
@@ -534,7 +483,6 @@
     ((("8" "."))(""))
     ((("9" "."))(""))
     ((("0" "."))(""))
-    ((("'" "."))(""))
     ((("," "."))(""))
     ((("." "."))(""))
     ((("p" "."))(""))
@@ -564,7 +512,7 @@
     ((("w" "."))(""))
     ((("v" "."))(""))
     ((("z" "."))(""))
-    ((("\057" "."))("Ϳ"))
+    ((("/" "."))("Ϳ"))
     ((("1" "p"))(""))
     ((("2" "p"))(""))
     ((("3" "p"))(""))
@@ -575,7 +523,6 @@
     ((("8" "p"))(""))
     ((("9" "p"))(""))
     ((("0" "p"))(""))
-    ((("'" "p"))(""))
     ((("," "p"))(""))
     ((("." "p"))(""))
     ((("p" "p"))(""))
@@ -605,9 +552,9 @@
     ((("w" "p"))(""))
     ((("v" "p"))(""))
     ((("z" "p"))(""))
-    ((("\057" "p"))(""))
+    ((("/" "p"))(""))
     ((("1" "y"))(""))
-    ((("2" "y"))(""))
+    ((("2" "y"))("ħ"))
     ((("3" "y"))(""))
     ((("4" "y"))(""))
     ((("5" "y"))(""))
@@ -616,7 +563,6 @@
     ((("8" "y"))(""))
     ((("9" "y"))(""))
     ((("0" "y"))(""))
-    ((("'" "y"))(""))
     ((("," "y"))(""))
     ((("." "y"))(""))
     ((("p" "y"))(""))
@@ -646,7 +592,7 @@
     ((("w" "y"))(""))
     ((("v" "y"))("Ψ"))
     ((("z" "y"))(""))
-    ((("\057" "y"))(""))
+    ((("/" "y"))(""))
     ((("1" "f"))(""))
     ((("2" "f"))(""))
     ((("3" "f"))(""))
@@ -657,7 +603,6 @@
     ((("8" "f"))(""))
     ((("9" "f"))(""))
     ((("0" "f"))("ɸ"))
-    ((("'" "f"))(""))
     ((("," "f"))(""))
     ((("." "f"))(""))
     ((("p" "f"))(""))
@@ -687,7 +632,7 @@
     ((("w" "f"))(""))
     ((("v" "f"))(""))
     ((("z" "f"))(""))
-    ((("\057" "f"))(""))
+    ((("/" "f"))(""))
     ((("1" "g"))(""))
     ((("2" "g"))(""))
     ((("3" "g"))(""))
@@ -698,7 +643,6 @@
     ((("8" "g"))(""))
     ((("9" "g"))(""))
     ((("0" "g"))(""))
-    ((("'" "g"))(""))
     ((("," "g"))(""))
     ((("." "g"))("Ĺ"))
     ((("p" "g"))(""))
@@ -728,7 +672,7 @@
     ((("w" "g"))(""))
     ((("v" "g"))(""))
     ((("z" "g"))("ž"))
-    ((("\057" "g"))(""))
+    ((("/" "g"))(""))
     ((("1" "c"))(""))
     ((("2" "c"))(""))
     ((("3" "c"))(""))
@@ -739,7 +683,6 @@
     ((("8" "c"))(""))
     ((("9" "c"))("°"))
     ((("0" "c"))(""))
-    ((("'" "c"))(""))
     ((("," "c"))(""))
     ((("." "c"))(""))
     ((("p" "c"))("ư"))
@@ -769,7 +712,7 @@
     ((("w" "c"))(""))
     ((("v" "c"))(""))
     ((("z" "c"))(""))
-    ((("\057" "c"))(""))
+    ((("/" "c"))(""))
     ((("1" "r"))(""))
     ((("2" "r"))(""))
     ((("3" "r"))(""))
@@ -780,7 +723,6 @@
     ((("8" "r"))(""))
     ((("9" "r"))("®"))
     ((("0" "r"))(""))
-    ((("'" "r"))(""))
     ((("," "r"))(""))
     ((("." "r"))(""))
     ((("p" "r"))("Ω"))
@@ -810,7 +752,7 @@
     ((("w" "r"))(""))
     ((("v" "r"))(""))
     ((("z" "r"))("Ŭ"))
-    ((("\057" "r"))(""))
+    ((("/" "r"))(""))
     ((("1" "l"))(""))
     ((("2" "l"))(""))
     ((("3" "l"))("̴"))
@@ -821,7 +763,6 @@
     ((("8" "l"))(""))
     ((("9" "l"))(""))
     ((("0" "l"))(""))
-    ((("'" "l"))(""))
     ((("," "l"))(""))
     ((("." "l"))(""))
     ((("p" "l"))(""))
@@ -851,7 +792,7 @@
     ((("w" "l"))(""))
     ((("v" "l"))(""))
     ((("z" "l"))(""))
-    ((("\057" "l"))(""))
+    ((("/" "l"))(""))
     ((("1" "a"))(""))
     ((("2" "a"))(""))
     ((("3" "a"))(""))
@@ -862,7 +803,6 @@
     ((("8" "a"))("Ļ"))
     ((("9" "a"))(""))
     ((("0" "a"))(""))
-    ((("'" "a"))(""))
     ((("," "a"))(""))
     ((("." "a"))(""))
     ((("p" "a"))(""))
@@ -892,7 +832,7 @@
     ((("w" "a"))(""))
     ((("v" "a"))(""))
     ((("z" "a"))(""))
-    ((("\057" "a"))(""))
+    ((("/" "a"))(""))
     ((("1" "o"))(""))
     ((("2" "o"))("Ǽ"))
     ((("3" "o"))(""))
@@ -903,7 +843,6 @@
     ((("8" "o"))(""))
     ((("9" "o"))(""))
     ((("0" "o"))(""))
-    ((("'" "o"))(""))
     ((("," "o"))(""))
     ((("." "o"))(""))
     ((("p" "o"))(""))
@@ -933,7 +872,7 @@
     ((("w" "o"))(""))
     ((("v" "o"))(""))
     ((("z" "o"))(""))
-    ((("\057" "o"))(""))
+    ((("/" "o"))(""))
     ((("1" "e"))(""))
     ((("2" "e"))(""))
     ((("3" "e"))(""))
@@ -944,7 +883,6 @@
     ((("8" "e"))("Ʈ"))
     ((("9" "e"))(""))
     ((("0" "e"))("ͼ"))
-    ((("'" "e"))(""))
     ((("," "e"))("Ȭ"))
     ((("." "e"))(""))
     ((("p" "e"))(""))
@@ -974,7 +912,7 @@
     ((("w" "e"))(""))
     ((("v" "e"))(""))
     ((("z" "e"))(""))
-    ((("\057" "e"))(""))
+    ((("/" "e"))(""))
     ((("1" "u"))(""))
     ((("2" "u"))(""))
     ((("3" "u"))(""))
@@ -985,7 +923,6 @@
     ((("8" "u"))(""))
     ((("9" "u"))(""))
     ((("0" "u"))(""))
-    ((("'" "u"))(""))
     ((("," "u"))(""))
     ((("." "u"))(""))
     ((("p" "u"))(""))
@@ -1015,7 +952,7 @@
     ((("w" "u"))(""))
     ((("v" "u"))(""))
     ((("z" "u"))(""))
-    ((("\057" "u"))(""))
+    ((("/" "u"))(""))
     ((("1" "i"))(""))
     ((("2" "i"))(""))
     ((("3" "i"))(""))
@@ -1026,7 +963,6 @@
     ((("8" "i"))(""))
     ((("9" "i"))(""))
     ((("0" "i"))(""))
-    ((("'" "i"))(""))
     ((("," "i"))(""))
     ((("." "i"))("ǰ"))
     ((("p" "i"))(""))
@@ -1056,7 +992,7 @@
     ((("w" "i"))(""))
     ((("v" "i"))(""))
     ((("z" "i"))(""))
-    ((("\057" "i"))("Ư"))
+    ((("/" "i"))("Ư"))
     ((("1" "d"))(""))
     ((("2" "d"))(""))
     ((("3" "d"))(""))
@@ -1067,7 +1003,6 @@
     ((("8" "d"))(""))
     ((("9" "d"))("ʩ"))
     ((("0" "d"))(""))
-    ((("'" "d"))(""))
     ((("," "d"))(""))
     ((("." "d"))(""))
     ((("p" "d"))(""))
@@ -1097,7 +1032,7 @@
     ((("w" "d"))(""))
     ((("v" "d"))("Ⱦ"))
     ((("z" "d"))(""))
-    ((("\057" "d"))(""))
+    ((("/" "d"))(""))
     ((("1" "h"))(""))
     ((("2" "h"))(""))
     ((("3" "h"))(""))
@@ -1108,7 +1043,6 @@
     ((("8" "h"))(""))
     ((("9" "h"))(""))
     ((("0" "h"))(""))
-    ((("'" "h"))(""))
     ((("," "h"))(""))
     ((("." "h"))("ʿ"))
     ((("p" "h"))("ʪ"))
@@ -1138,7 +1072,7 @@
     ((("w" "h"))(""))
     ((("v" "h"))(""))
     ((("z" "h"))(""))
-    ((("\057" "h"))(""))
+    ((("/" "h"))(""))
     ((("1" "t"))(""))
     ((("2" "t"))(""))
     ((("3" "t"))(""))
@@ -1149,7 +1083,6 @@
     ((("8" "t"))(""))
     ((("9" "t"))(""))
     ((("0" "t"))(""))
-    ((("'" "t"))(""))
     ((("," "t"))(""))
     ((("." "t"))(""))
     ((("p" "t"))(""))
@@ -1179,7 +1112,7 @@
     ((("w" "t"))(""))
     ((("v" "t"))(""))
     ((("z" "t"))(""))
-    ((("\057" "t"))(""))
+    ((("/" "t"))(""))
     ((("1" "n"))(""))
     ((("2" "n"))(""))
     ((("3" "n"))(""))
@@ -1190,7 +1123,6 @@
     ((("8" "n"))(""))
     ((("9" "n"))(""))
     ((("0" "n"))(""))
-    ((("'" "n"))(""))
     ((("," "n"))(""))
     ((("." "n"))(""))
     ((("p" "n"))(""))
@@ -1220,7 +1152,7 @@
     ((("w" "n"))("ģ"))
     ((("v" "n"))(""))
     ((("z" "n"))(""))
-    ((("\057" "n"))(""))
+    ((("/" "n"))(""))
     ((("1" "s"))(""))
     ((("2" "s"))(""))
     ((("3" "s"))(""))
@@ -1231,7 +1163,6 @@
     ((("8" "s"))(""))
     ((("9" "s"))(""))
     ((("0" "s"))(""))
-    ((("'" "s"))(""))
     ((("," "s"))(""))
     ((("." "s"))(""))
     ((("p" "s"))(""))
@@ -1261,7 +1192,7 @@
     ((("w" "s"))("ͺ"))
     ((("v" "s"))(""))
     ((("z" "s"))(""))
-    ((("\057" "s"))(""))
+    ((("/" "s"))(""))
     ((("1" ";"))(""))
     ((("2" ";"))(""))
     ((("3" ";"))(""))
@@ -1272,7 +1203,6 @@
     ((("8" ";"))("Ʒ"))
     ((("9" ";"))("ƫ"))
     ((("0" ";"))(""))
-    ((("'" ";"))(""))
     ((("," ";"))(""))
     ((("." ";"))(""))
     ((("p" ";"))(""))
@@ -1302,7 +1232,7 @@
     ((("w" ";"))(""))
     ((("v" ";"))(""))
     ((("z" ";"))(""))
-    ((("\057" ";"))(""))
+    ((("/" ";"))(""))
     ((("1" "q"))(""))
     ((("2" "q"))(""))
     ((("3" "q"))(""))
@@ -1313,7 +1243,6 @@
     ((("8" "q"))("ú"))
     ((("9" "q"))(""))
     ((("0" "q"))(""))
-    ((("'" "q"))(""))
     ((("," "q"))("Ū"))
     ((("." "q"))(""))
     ((("p" "q"))(""))
@@ -1343,7 +1272,7 @@
     ((("w" "q"))(""))
     ((("v" "q"))(""))
     ((("z" "q"))(""))
-    ((("\057" "q"))(""))
+    ((("/" "q"))(""))
     ((("1" "j"))(""))
     ((("2" "j"))(""))
     ((("3" "j"))(""))
@@ -1354,7 +1283,6 @@
     ((("8" "j"))(""))
     ((("9" "j"))("ź"))
     ((("0" "j"))(""))
-    ((("'" "j"))(""))
     ((("," "j"))(""))
     ((("." "j"))(""))
     ((("p" "j"))(""))
@@ -1384,7 +1312,7 @@
     ((("w" "j"))("ĥ"))
     ((("v" "j"))(""))
     ((("z" "j"))(""))
-    ((("\057" "j"))(""))
+    ((("/" "j"))(""))
     ((("1" "k"))(""))
     ((("2" "k"))(""))
     ((("3" "k"))(""))
@@ -1395,7 +1323,6 @@
     ((("8" "k"))(""))
     ((("9" "k"))("Ű"))
     ((("0" "k"))("̦"))
-    ((("'" "k"))(""))
     ((("," "k"))(""))
     ((("." "k"))(""))
     ((("p" "k"))(""))
@@ -1425,7 +1352,7 @@
     ((("w" "k"))(""))
     ((("v" "k"))(""))
     ((("z" "k"))(""))
-    ((("\057" "k"))(""))
+    ((("/" "k"))(""))
     ((("1" "x"))(""))
     ((("2" "x"))(""))
     ((("3" "x"))(""))
@@ -1436,7 +1363,6 @@
     ((("8" "x"))(""))
     ((("9" "x"))(""))
     ((("0" "x"))("Ȩ"))
-    ((("'" "x"))(""))
     ((("," "x"))(""))
     ((("." "x"))(""))
     ((("p" "x"))(""))
@@ -1466,7 +1392,7 @@
     ((("w" "x"))(""))
     ((("v" "x"))(""))
     ((("z" "x"))("Ƚ"))
-    ((("\057" "x"))(""))
+    ((("/" "x"))(""))
     ((("1" "b"))(""))
     ((("2" "b"))(""))
     ((("3" "b"))(""))
@@ -1477,7 +1403,6 @@
     ((("8" "b"))(""))
     ((("9" "b"))(""))
     ((("0" "b"))(""))
-    ((("'" "b"))(""))
     ((("," "b"))(""))
     ((("." "b"))(""))
     ((("p" "b"))(""))
@@ -1507,7 +1432,7 @@
     ((("w" "b"))(""))
     ((("v" "b"))("ʡ"))
     ((("z" "b"))(""))
-    ((("\057" "b"))(""))
+    ((("/" "b"))(""))
     ((("1" "m"))(""))
     ((("2" "m"))(""))
     ((("3" "m"))(""))
@@ -1518,7 +1443,6 @@
     ((("8" "m"))(""))
     ((("9" "m"))(""))
     ((("0" "m"))(""))
-    ((("'" "m"))(""))
     ((("," "m"))(""))
     ((("." "m"))(""))
     ((("p" "m"))(""))
@@ -1548,7 +1472,7 @@
     ((("w" "m"))(""))
     ((("v" "m"))(""))
     ((("z" "m"))("Ƿ"))
-    ((("\057" "m"))(""))
+    ((("/" "m"))(""))
     ((("1" "w"))(""))
     ((("2" "w"))(""))
     ((("3" "w"))(""))
@@ -1559,7 +1483,6 @@
     ((("8" "w"))(""))
     ((("9" "w"))(""))
     ((("0" "w"))(""))
-    ((("'" "w"))(""))
     ((("," "w"))(""))
     ((("." "w"))(""))
     ((("p" "w"))(""))
@@ -1589,7 +1512,7 @@
     ((("w" "w"))(""))
     ((("v" "w"))(""))
     ((("z" "w"))(""))
-    ((("\057" "w"))(""))
+    ((("/" "w"))(""))
     ((("1" "v"))(""))
     ((("2" "v"))(""))
     ((("3" "v"))(""))
@@ -1600,7 +1523,6 @@
     ((("8" "v"))(""))
     ((("9" "v"))(""))
     ((("0" "v"))("Υ"))
-    ((("'" "v"))(""))
     ((("," "v"))(""))
     ((("." "v"))(""))
     ((("p" "v"))(""))
@@ -1630,7 +1552,7 @@
     ((("w" "v"))(""))
     ((("v" "v"))(""))
     ((("z" "v"))(""))
-    ((("\057" "v"))(""))
+    ((("/" "v"))(""))
     ((("1" "z"))(""))
     ((("2" "z"))(""))
     ((("3" "z"))(""))
@@ -1641,7 +1563,6 @@
     ((("8" "z"))(""))
     ((("9" "z"))(""))
     ((("0" "z"))(""))
-    ((("'" "z"))(""))
     ((("," "z"))(""))
     ((("." "z"))(""))
     ((("p" "z"))(""))
@@ -1671,48 +1592,47 @@
     ((("w" "z"))(""))
     ((("v" "z"))(""))
     ((("z" "z"))(""))
-    ((("\057" "z"))(""))
-    ((("1" "\057"))(""))
-    ((("2" "\057"))(""))
-    ((("3" "\057"))(""))
-    ((("4" "\057"))("Ȣ"))
-    ((("5" "\057"))(""))
-    ((("6" "\057"))(""))
-    ((("7" "\057"))(""))
-    ((("8" "\057"))(""))
-    ((("9" "\057"))(""))
-    ((("0" "\057"))(""))
-    ((("'" "\057"))(""))
-    ((("," "\057"))(""))
-    ((("." "\057"))("ȿ"))
-    ((("p" "\057"))(""))
-    ((("y" "\057"))("ô"))
-    ((("f" "\057"))(""))
-    ((("g" "\057"))("Ʋ"))
-    ((("c" "\057"))(""))
-    ((("r" "\057"))(""))
-    ((("l" "\057"))(""))
-    ((("a" "\057"))(""))
-    ((("o" "\057"))(""))
-    ((("e" "\057"))(""))
-    ((("u" "\057"))("Φ"))
-    ((("i" "\057"))(""))
-    ((("d" "\057"))(""))
-    ((("h" "\057"))(""))
-    ((("t" "\057"))(""))
-    ((("n" "\057"))(""))
-    ((("s" "\057"))(""))
-    (((";" "\057"))(""))
-    ((("q" "\057"))(""))
-    ((("j" "\057"))(""))
-    ((("k" "\057"))(""))
-    ((("x" "\057"))(""))
-    ((("b" "\057"))("ñ"))
-    ((("m" "\057"))(""))
-    ((("w" "\057"))("ȴ"))
-    ((("v" "\057"))(""))
-    ((("z" "\057"))(""))
-    ((("\057" "\057"))(""))))
+    ((("/" "z"))(""))
+    ((("1" "/"))(""))
+    ((("2" "/"))(""))
+    ((("3" "/"))(""))
+    ((("4" "/"))("Ȣ"))
+    ((("5" "/"))(""))
+    ((("6" "/"))(""))
+    ((("7" "/"))(""))
+    ((("8" "/"))(""))
+    ((("9" "/"))(""))
+    ((("0" "/"))(""))
+    ((("," "/"))(""))
+    ((("." "/"))("ȿ"))
+    ((("p" "/"))(""))
+    ((("y" "/"))("ô"))
+    ((("f" "/"))(""))
+    ((("g" "/"))("Ʋ"))
+    ((("c" "/"))(""))
+    ((("r" "/"))(""))
+    ((("l" "/"))(""))
+    ((("a" "/"))(""))
+    ((("o" "/"))(""))
+    ((("e" "/"))(""))
+    ((("u" "/"))("Φ"))
+    ((("i" "/"))(""))
+    ((("d" "/"))(""))
+    ((("h" "/"))(""))
+    ((("t" "/"))(""))
+    ((("n" "/"))(""))
+    ((("s" "/"))(""))
+    (((";" "/"))(""))
+    ((("q" "/"))(""))
+    ((("j" "/"))(""))
+    ((("k" "/"))(""))
+    ((("x" "/"))(""))
+    ((("b" "/"))("ñ"))
+    ((("m" "/"))(""))
+    ((("w" "/"))("ȴ"))
+    ((("v" "/"))(""))
+    ((("z" "/"))(""))
+    ((("/" "/"))(""))))
 
 (define tcode-init-handler
   (lambda (id im arg)
